@@ -1,6 +1,9 @@
 #' @keywords AIRSIS
 #' @export
-#' @title Obain AIRSIS Data and Create ws_monitor Object
+#' @import MazamaCoreUtils
+#'
+#' @title Obain AIRSIS data and create ws_monitor object
+#'
 #' @param startdate desired start date (integer or character representing YYYYMMDD[HH])
 #' @param enddate desired end date (integer or character representing YYYYMMDD[HH])
 #' @param provider identifier used to modify baseURL \code{['APCD'|'USFS']}
@@ -17,9 +20,9 @@
 #' @description Obtains monitor data from an AIRSIS webservice and converts
 #' it into a quality controlled, metadata enhanced \emph{ws_monitor} object
 #' ready for use with all \code{monitor_~} functions.
-#' 
+#'
 #' Steps involved include:
-#' 
+#'
 #' \enumerate{
 #'  \item{download CSV text}
 #'  \item{parse CSV text}
@@ -28,10 +31,10 @@
 #'  \item{enhance metadata to include: elevation, timezone, state, country, site name}
 #'  \item{reshape AIRSIS data into deployment-by-property \code{meta} and and time-by-deployment \code{data} dataframes}
 #' }
-#' 
+#'
 #' QC parameters that can be passed in the \code{\dots} include the following
 #' valid data ranges as taken from \code{airsis_EBAMQualityControl()}:
-#' 
+#'
 #' \itemize{
 #' \item{\code{valid_Longitude=c(-180,180)}}
 #' \item{\code{valid_Latitude=c(-90,90)}}
@@ -42,9 +45,9 @@
 #' \item{\code{valid_RHi = c(-Inf,45)}}
 #' \item{\code{valid_Conc = c(-Inf,5.000)}}
 #' }
-#' 
+#'
 #' Note that appropriate values for QC thresholds will depend on the type of monitor.
-#' 
+#'
 #' @note The downloaded CSV may be saved to a local file by providing an argument to the \code{saveFile} parameter.
 #' @seealso \code{\link{airsis_downloadData}}
 #' @seealso \code{\link{airsis_parseData}}
@@ -56,21 +59,25 @@
 #' \dontrun{
 #' initializeMazamaSpatialUtils()
 #' usfs_1013 <- airsis_createMonitorObject(20150301, 20150831, 'USFS', unitID='1013')
-#' monitorLeaflet(usfs_1013)
+#' monitor_leaflet(usfs_1013)
 #' }
 
-airsis_createMonitorObject <- function(startdate=strftime(lubridate::now(),"%Y010100",tz="UTC"),
-                                       enddate=strftime(lubridate::now(),"%Y%m%d23",tz="UTC"),
-                                       provider=NULL,
-                                       unitID=NULL,
-                                       clusterDiameter=1000,
-                                       zeroMinimum=TRUE,
-                                       baseUrl="http://xxxx.airsis.com/vision/common/CSVExport.aspx?",
-                                       saveFile=NULL,
-                                       existingMeta=NULL,
-                                       addGoogleMeta=FALSE,
-                                       addEsriMeta=FALSE,
-                                       ...) {
+airsis_createMonitorObject <- function(
+  startdate = strftime(lubridate::now(), "%Y010100", tz = "UTC"),
+  enddate = strftime(lubridate::now(), "%Y%m%d23", tz = "UTC"),
+  provider = NULL,
+  unitID = NULL,
+  clusterDiameter = 1000,
+  zeroMinimum = TRUE,
+  baseUrl = "http://xxxx.airsis.com/vision/common/CSVExport.aspx?",
+  saveFile = NULL,
+  existingMeta = NULL,
+  addGoogleMeta = FALSE,
+  addEsriMeta = FALSE,
+  ...
+) {
+
+  logger.debug(" ----- airsis_createMonitorObject() ----- ")
 
   # Sanity checks
   if ( is.null(provider) ) {
@@ -88,68 +95,68 @@ airsis_createMonitorObject <- function(startdate=strftime(lubridate::now(),"%Y01
     logger.error("Cannot parse 'startdate' with %d characters", startdateCount)
     stop(paste0("Cannot parse 'startdate' with ",startdateCount," characters"))
   }
-  
+
   enddateCount <- stringr::str_count(as.character(enddate))
   if ( !enddateCount %in% c(8,10,12) ) {
     logger.error("Cannot parse 'enddate' with %d characters", enddateCount)
     stop(paste0("Cannot parse 'enddate' with ",enddateCount," characters"))
   }
-  
+
   # Read in AIRSIS .csv data
   fileString <- airsis_downloadData(startdate, enddate, provider, unitID, baseUrl)
-  
+
   # Optionally save as a raw .csv file
   if ( !is.null(saveFile) ) {
-    result <- try( cat(fileString, file=saveFile),
-                   silent=TRUE )
+    result <- try( cat(fileString, file = saveFile),
+                   silent = TRUE )
     if ( "try-error" %in% class(result) ) {
       err_msg <- geterrmessage()
       logger.warn("Unable to save data to local file %s: %s", saveFile, err_msg)
     }
     # NOTE:  Processing continues even if we fail to write the local file
   }
-  
+
   # Read csv raw data into a dataframe
-  logger.debug("Parsing data ...")
+  logger.trace("Parsing data ...")
   tbl <- airsis_parseData(fileString)
-  
+
   # Apply monitor-appropriate QC to the dataframe
-  logger.debug("Applying QC logic ...")
+  logger.trace("Applying QC logic ...")
   tbl <- airsis_qualityControl(tbl, ...)
-  
+
   # See if anything gets through QC
   if ( nrow(tbl) == 0 ) {
     logger.warn("No data remaining after QC") # This is more of a warning than some error in the data.
     stop("No data remaining after QC")
   }
-  
+
   # Add clustering information to identify unique deployments
-  logger.debug("Clustering ...")
+  logger.trace("Clustering ...")
   tbl <- addClustering(tbl, lonVar='Longitude', latVar='Latitude', clusterDiameter=clusterDiameter)
-  
+
   # Create 'meta' dataframe of site properties organized as monitorID-by-property
   # NOTE:  This step will create a uniformly named set of properties and will
   # NOTE:  add site-specific information like timezone, elevation, address, etc.
-  logger.debug("Creating 'meta' dataframe ...")
+  logger.trace("Creating 'meta' dataframe ...")
   meta <- airsis_createMetaDataframe(tbl, provider, unitID, 'AIRSIS',
                                      existingMeta = existingMeta,
                                      addGoogleMeta = addGoogleMeta,
                                      addEsriMeta = addEsriMeta)
-  
+
   # Create 'data' dataframe of PM2.5 values organized as time-by-monitorID
-  logger.debug("Creating 'data' dataframe ...")
+  logger.trace("Creating 'data' dataframe ...")
   data <- airsis_createDataDataframe(tbl, meta)
-  
+
   # Create the 'ws_monitor' object
   ws_monitor <- list(meta=meta, data=data)
   ws_monitor <- structure(ws_monitor, class = c("ws_monitor", "list"))
-  
+
   # Reset all negative values that made it through QC to zero
   if ( zeroMinimum ) {
-    logger.debug("Reset negative values to zero ...")
+    logger.trace("Reset negative values to zero ...")
     ws_monitor <- monitor_replaceData(ws_monitor, data < 0, 0)
   }
-  
+
   return(ws_monitor)
-  
+
 }
